# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"grid_search": "00_core.ipynb",
         "random_search": "00_core.ipynb",
         "latin_hyper_cube": "00_core.ipynb",
         "jittered_sampling": "00_core.ipynb",
         "multi_jittered": "00_core.ipynb",
         "is_valid": "00_core.ipynb",
         "poisson_disk": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://ELC.github.io/progressive_samplers/"

git_url = "https://github.com/ELC/progressive_samplers/tree/master/"

def custom_doc_links(name): return None
